"""A library to help interacting with omegaUp.

This is composed of two modules:

- [**`omegaup.api`**](./omegaup/api/) helps interacting with [omegaUp's
  API](https://github.com/omegaup/omegaup/blob/master/frontend/server/src/Controllers/README.md)
  and is auto-generated with correct types and the docstrings straight from the
  code.
- [**`omegaup.validator`**](./omegaup/validator/) has runtime helper functions
  to aid in problem validation.
"""
